pub struct PetComputedSecondaryStat {
pub attribute_id: AttributeId,
pub value: i64,
}Fields
attribute_id: AttributeIdvalue: i64Trait Implementations
Sourceimpl Clone for PetComputedSecondaryStat
impl Clone for PetComputedSecondaryStat
Sourcefn clone(&self) -> PetComputedSecondaryStat
fn clone(&self) -> PetComputedSecondaryStat
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for PetComputedSecondaryStat
impl CustomType for PetComputedSecondaryStat
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for PetComputedSecondaryStat
impl Debug for PetComputedSecondaryStat
Sourceimpl<'de> Deserialize<'de> for PetComputedSecondaryStat
impl<'de> Deserialize<'de> for PetComputedSecondaryStat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PetComputedSecondaryStat
impl JsonSchema for PetComputedSecondaryStat
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PetComputedSecondaryStat
impl PartialEq for PetComputedSecondaryStat
Sourceimpl Serialize for PetComputedSecondaryStat
impl Serialize for PetComputedSecondaryStat
Sourceimpl Tsify for PetComputedSecondaryStat
impl Tsify for PetComputedSecondaryStat
const DECL: &'static str = "export interface PetComputedSecondaryStat {\n attribute_id: AttributeId;\n value: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for PetComputedSecondaryStat
impl StructuralPartialEq for PetComputedSecondaryStat