pub struct PetDrop {
pub template: PetTemplate,
pub is_new: bool,
pub is_checkpoint: bool,
}Fields
template: PetTemplateis_new: boolis_checkpoint: boolTrait Implementations
Sourceimpl CustomType for PetDrop
impl CustomType for PetDrop
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl<'de> Deserialize<'de> for PetDrop
impl<'de> Deserialize<'de> for PetDrop
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PetDrop
impl JsonSchema for PetDrop
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for PetDrop
impl Tsify for PetDrop
const DECL: &'static str = "export interface PetDrop {\n template: PetTemplate;\n is_new: boolean;\n is_checkpoint: boolean;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for PetDrop
impl StructuralPartialEq for PetDrop