pub struct PetRarity {
pub id: PetRarityId,
pub name: I18nString,
pub order: u64,
pub color: String,
pub bg_color: String,
pub icon_path: String,
pub square_icon_path: String,
}Fields
id: PetRarityIdname: I18nStringorder: u64color: Stringbg_color: Stringicon_path: Stringsquare_icon_path: StringTrait Implementations
Sourceimpl CustomType for PetRarity
impl CustomType for PetRarity
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl<'de> Deserialize<'de> for PetRarity
impl<'de> Deserialize<'de> for PetRarity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PetRarity
impl JsonSchema for PetRarity
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for PetRarity
impl Tsify for PetRarity
const DECL: &'static str = "export interface PetRarity {\n id: PetRarityId;\n name: I18nString;\n order: number;\n color: string;\n bg_color: string;\n icon_path: string;\n square_icon_path: string;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for PetRarity
impl StructuralPartialEq for PetRarity