pub struct PetSecondaryStat {
pub attribute_id: AttributeId,
pub base_value: i64,
pub per_level_value: i64,
}Fields
attribute_id: AttributeIdbase_value: i64per_level_value: i64Trait Implementations
Sourceimpl Clone for PetSecondaryStat
impl Clone for PetSecondaryStat
Sourcefn clone(&self) -> PetSecondaryStat
fn clone(&self) -> PetSecondaryStat
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for PetSecondaryStat
impl CustomType for PetSecondaryStat
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for PetSecondaryStat
impl Debug for PetSecondaryStat
Sourceimpl<'de> Deserialize<'de> for PetSecondaryStat
impl<'de> Deserialize<'de> for PetSecondaryStat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PetSecondaryStat
impl JsonSchema for PetSecondaryStat
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PetSecondaryStat
impl PartialEq for PetSecondaryStat
Sourceimpl Serialize for PetSecondaryStat
impl Serialize for PetSecondaryStat
Sourceimpl Tsify for PetSecondaryStat
impl Tsify for PetSecondaryStat
const DECL: &'static str = "export interface PetSecondaryStat {\n attribute_id: AttributeId;\n base_value: number;\n per_level_value: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for PetSecondaryStat
impl StructuralPartialEq for PetSecondaryStat