pub struct PetTemplate {Show 13 fields
pub id: PetId,
pub name: I18nString,
pub icon_path: String,
pub spine_path: String,
pub rarity_id: PetRarityId,
pub stats: Vec<PetSecondaryStat>,
pub active_ability_id: Option<AbilityId>,
pub passive_ability_id: Option<AbilityId>,
pub charge_rate_on_damage_dealt: i64,
pub charge_rate_on_damage_taken: i64,
pub charge_rate_on_skill_use: i64,
pub max_charge: i64,
pub is_gacha_pet: bool,
}Fields
id: PetIdname: I18nStringicon_path: Stringspine_path: Stringrarity_id: PetRarityIdstats: Vec<PetSecondaryStat>active_ability_id: Option<AbilityId>passive_ability_id: Option<AbilityId>charge_rate_on_damage_dealt: i64charge_rate_on_damage_taken: i64charge_rate_on_skill_use: i64max_charge: i64is_gacha_pet: boolTrait Implementations
Sourceimpl Clone for PetTemplate
impl Clone for PetTemplate
Sourcefn clone(&self) -> PetTemplate
fn clone(&self) -> PetTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for PetTemplate
impl CustomType for PetTemplate
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for PetTemplate
impl Debug for PetTemplate
Sourceimpl Default for PetTemplate
impl Default for PetTemplate
Sourcefn default() -> PetTemplate
fn default() -> PetTemplate
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PetTemplate
impl<'de> Deserialize<'de> for PetTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromWasmAbi for PetTemplatewhere
Self: DeserializeOwned,
impl FromWasmAbi for PetTemplatewhere
Self: DeserializeOwned,
Sourceimpl JsonSchema for PetTemplate
impl JsonSchema for PetTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for PetTemplatewhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for PetTemplatewhere
Self: DeserializeOwned,
Sourceimpl PartialEq for PetTemplate
impl PartialEq for PetTemplate
Sourceimpl RefFromWasmAbi for PetTemplatewhere
Self: DeserializeOwned,
impl RefFromWasmAbi for PetTemplatewhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<PetTemplate>
type Anchor = SelfOwner<PetTemplate>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for PetTemplate
impl Serialize for PetTemplate
Sourceimpl Tsify for PetTemplate
impl Tsify for PetTemplate
const DECL: &'static str = "export interface PetTemplate {\n id: PetId;\n name: I18nString;\n icon_path: string;\n spine_path: string;\n rarity_id: PetRarityId;\n stats: PetSecondaryStat[];\n active_ability_id: AbilityId | null;\n passive_ability_id: AbilityId | null;\n charge_rate_on_damage_dealt: number;\n charge_rate_on_damage_taken: number;\n charge_rate_on_skill_use: number;\n max_charge: number;\n is_gacha_pet: boolean;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for PetTemplatewhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for PetTemplatewhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl WasmDescribeVector for PetTemplate
impl WasmDescribeVector for PetTemplate
impl Eq for PetTemplate
impl StructuralPartialEq for PetTemplate